var NAVTREEINDEX8 =
{
"group__API__Performance__Model.html#aa82fae955253d333733d34fe4a44e298":[25,20,5,1],
"group__API__Performance__Model.html#ab1a7822099d984503f1c67d45ab6f4b8":[25,20,2,2],
"group__API__Performance__Model.html#ab718a53c300f99766bdc42ca1909b49b":[25,20,4,9],
"group__API__Performance__Model.html#ab73609496a2f81bca58a7c864b434441":[25,20,0,0],
"group__API__Performance__Model.html#ab98cb01511c0fc3dfccdee0265137440":[25,20,6,7],
"group__API__Performance__Model.html#ac4ea9dce00af99aa0f3eb21e4d4300f6":[25,20,6,3],
"group__API__Performance__Model.html#ac651825cdcd22fb9e6389d73c1b4f275":[25,20,4,11],
"group__API__Performance__Model.html#acce4202682709ec0e1f0f22ecc55d1d0":[25,20,4,1],
"group__API__Performance__Model.html#ad141b7ae874d40dabeea131474ba29c0":[25,20,4,13],
"group__API__Performance__Model.html#ad691b4ef9fc2367e13aba7d578832763":[25,20,4,4],
"group__API__Performance__Model.html#adb5e09576697a74975467483d3c080a2":[25,20,2,5],
"group__API__Performance__Model.html#addc058e80e8075ecb7474da3a3de3885":[25,20,1,0],
"group__API__Performance__Model.html#ae37737aa0b7abc5f5813bf61814d996f":[25,20,6,8],
"group__API__Performance__Model.html#ae85f08cd76b524e074b5d1746fe2610a":[25,20,5,2],
"group__API__Performance__Model.html#aea02b90f7e91d139c991a730594c841d":[25,20,4,16],
"group__API__Performance__Model.html#aec35b7054c3d28730425f47c61b8a297":[25,20,4,14],
"group__API__Performance__Model.html#af39728c1095f645bf195430903532a36":[25,20,2,7],
"group__API__Performance__Model.html#af5497d7f073aa115e25d6d1a32c2e668":[25,20,4,10],
"group__API__Performance__Model.html#afb6b1e89bf7820131bddf970bb0df58b":[25,20,4,6],
"group__API__Performance__Model.html#afe2d561aaba7bf1ad1cf03974ee8c53c":[25,20,6,0],
"group__API__Performance__Model.html#ga03fc571c3f6132339a75004899f577af":[25,20,22],
"group__API__Performance__Model.html#ga299bb26d02dfb4802c633d06b8b5ff8b":[25,20,8],
"group__API__Performance__Model.html#ga2ec4c9ec1ac320aae99e31871bfed90d":[25,20,20],
"group__API__Performance__Model.html#ga31ef3dfa1dc711b7f24bea9aabd484e3":[25,20,16],
"group__API__Performance__Model.html#ga4e733252c29912beb0ac7bb46f2b6d16":[25,20,34],
"group__API__Performance__Model.html#ga5ab7213f5c229c16e783004853fcba4c":[25,20,13],
"group__API__Performance__Model.html#ga712a3e3498f113efb81c42c6b7a48335":[25,20,29],
"group__API__Performance__Model.html#ga73e84b64af1ce96eec9b1c83e7468c60":[25,20,21],
"group__API__Performance__Model.html#ga7562bd09e4894eeb15391f2a0f21cf00":[25,20,24],
"group__API__Performance__Model.html#ga767f88b087d4b0bf4086ade9bb673826":[25,20,31],
"group__API__Performance__Model.html#ga77915973bf2f03bd70fb84ee4c9c51a0":[25,20,32],
"group__API__Performance__Model.html#ga848da744e39816ba34f1944817b1f4b1":[25,20,30],
"group__API__Performance__Model.html#ga88213c9b2cbde1ea181452e734eedbf8":[25,20,10],
"group__API__Performance__Model.html#ga8dd71674604b4449bf3cabd5e85012c1":[25,20,11],
"group__API__Performance__Model.html#ga91475a84dd5fac13d3785faecf9e4301":[25,20,18],
"group__API__Performance__Model.html#ga96746e1665eeffec32a82a465325f7dc":[25,20,14],
"group__API__Performance__Model.html#ga9a4af8d1b5a3486a5a21c72dd4a6c4c2":[25,20,33],
"group__API__Performance__Model.html#ga9cb408a75aa1ba72c2ada1c9c633a589":[25,20,15],
"group__API__Performance__Model.html#gaa15b18c0f49520a33e96ea8c48c5801d":[25,20,23],
"group__API__Performance__Model.html#gaac6a7d27c0033f882722892237e82d82":[25,20,17],
"group__API__Performance__Model.html#gac4075eddef3625eccbbc9f1670c69244":[25,20,28],
"group__API__Performance__Model.html#gac57a753ca50acdfb524ac688c2e727e8":[25,20,9],
"group__API__Performance__Model.html#gadb2ada1d388826505ff79352a469cac3":[25,20,19],
"group__API__Performance__Model.html#gae161a7cae376f3fc831a2b764e8144e6":[25,20,7],
"group__API__Performance__Model.html#gae344bb6e6f89f5734461986d3c709f0f":[25,20,26],
"group__API__Performance__Model.html#gae99274bc3bc2d6692c0e22113971b9ef":[25,20,27],
"group__API__Performance__Model.html#gaecb9341bff471557abbb63a966449481":[25,20,25],
"group__API__Performance__Model.html#gaf02aaa9dd29cab640329f496aaefcc65":[25,20,12],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a286175813689c4623e1558ed7fe317f5":[25,20,7,5],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a3955069fdbc345f5d70f59b9127e1cd2":[25,20,7,0],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a4c58334b6de6683d02d9d927e1dba901":[25,20,7,6],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a58209f94a343ef0a116881cae2a3a405":[25,20,7,4],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a626db2177027908d7d6f4753807bca8b":[25,20,7,2],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6a98a0f2cda640f231009f262e676f4851":[25,20,7,1],
"group__API__Performance__Model.html#ggae161a7cae376f3fc831a2b764e8144e6ab1ea457716c143f155593a2112e38f35":[25,20,7,3],
"group__API__Performance__Model.html#structstarpu__perfmodel":[25,20,6],
"group__API__Performance__Model.html#structstarpu__perfmodel__arch":[25,20,1],
"group__API__Performance__Model.html#structstarpu__perfmodel__device":[25,20,0],
"group__API__Performance__Model.html#structstarpu__perfmodel__history__entry":[25,20,2],
"group__API__Performance__Model.html#structstarpu__perfmodel__history__list":[25,20,3],
"group__API__Performance__Model.html#structstarpu__perfmodel__per__arch":[25,20,5],
"group__API__Performance__Model.html#structstarpu__perfmodel__regression__model":[25,20,4],
"group__API__Profiling.html":[25,40],
"group__API__Profiling.html#a029068c588c17476bf07a4a4a2bd690b":[25,40,2,2],
"group__API__Profiling.html#a050199a48e0073f892cd6dd9049a4edf":[25,40,1,2],
"group__API__Profiling.html#a0a43cc6fa5233d8d7e7ab0821607068c":[25,40,0,6],
"group__API__Profiling.html#a0f7924b2532ba262f2b3a906f2c94a92":[25,40,1,4],
"group__API__Profiling.html#a19a06e7ef34a9a4587e77949ded36644":[25,40,0,13],
"group__API__Profiling.html#a24037f0f53113b23f32c7af7a39f982d":[25,40,1,14],
"group__API__Profiling.html#a2c480622424a849f893cd322549642a5":[25,40,1,9],
"group__API__Profiling.html#a3296b9aa5339bf99f00f5377517c2390":[25,40,0,12],
"group__API__Profiling.html#a34ad3d96e949d8030473300e13aa1c0c":[25,40,2,3],
"group__API__Profiling.html#a3a1a7c8e4ce2552a0f96a8dd4f9ad37f":[25,40,0,0],
"group__API__Profiling.html#a46492a6afad2c9069b84110d6d9e86be":[25,40,2,1],
"group__API__Profiling.html#a4ad1ae7ed15ea7001b5dc8e1d9579235":[25,40,0,11],
"group__API__Profiling.html#a4d1622e57181ef92126d0f100f9316bd":[25,40,1,11],
"group__API__Profiling.html#a52240aa53000a12a7b913f9f5822e032":[25,40,1,15],
"group__API__Profiling.html#a55f39da3b4c223d4cfc5bf7456692179":[25,40,0,3],
"group__API__Profiling.html#a595e50d7029c774d275a4c60f16a0ada":[25,40,1,8],
"group__API__Profiling.html#a5f76b7a4cc42a28735e0871439040319":[25,40,1,13],
"group__API__Profiling.html#a650860076a4d4c07929e97ec64386724":[25,40,0,2],
"group__API__Profiling.html#a67bee4aeadbec19556780f8328110957":[25,40,1,7],
"group__API__Profiling.html#a6e85ac77428f572c5380e283b943459c":[25,40,0,16],
"group__API__Profiling.html#a73a1303e033dffe94ff162e8e21122d1":[25,40,1,12],
"group__API__Profiling.html#a78e32404bdff71292562d2dc5892061c":[25,40,0,15],
"group__API__Profiling.html#a8032d6b4c3391555b255718d7da4279c":[25,40,2,0],
"group__API__Profiling.html#a8786d0be02dcf901ae7cd8a295b30293":[25,40,1,3],
"group__API__Profiling.html#a89ac253d44d475a9d2dfcb9153bd4b3a":[25,40,1,10],
"group__API__Profiling.html#a8f1fe52f21a7fc58860cf2f163ec868a":[25,40,0,5],
"group__API__Profiling.html#a8f4291afbbd7fcf885a3d30a72f2dd78":[25,40,0,10],
"group__API__Profiling.html#a9e1ae88eb46e9b9867cb41d0584ace7b":[25,40,0,4],
"group__API__Profiling.html#aa28c145b4543cceed05a1bba0478577e":[25,40,0,1],
"group__API__Profiling.html#aae49335c3c189b58103cb649fc169096":[25,40,1,1],
"group__API__Profiling.html#aae7bd9f557dffe9883629df980eee606":[25,40,0,9],
"group__API__Profiling.html#ab8de457be74df606d29c3efa1169998a":[25,40,0,7],
"group__API__Profiling.html#acc882d8569e28d51fd5e820962fed773":[25,40,1,5],
"group__API__Profiling.html#ada5d73c7df113b540914f84e95963fb9":[25,40,1,6],
"group__API__Profiling.html#ade189cd6175d789db1eb6bfad19b3e35":[25,40,0,8],
"group__API__Profiling.html#aec88f33a8b4777727d80296c16d85f24":[25,40,0,14],
"group__API__Profiling.html#aed6a8be9b919f03e093912bfc44c5559":[25,40,1,0],
"group__API__Profiling.html#ga1e388939370daaf139c73678e413f00a":[25,40,3],
"group__API__Profiling.html#ga4e4f9fb593d29219a1109062ba9d72ef":[25,40,22],
"group__API__Profiling.html#ga6511f50290edcabbdf605a1b74746645":[25,40,21],
"group__API__Profiling.html#ga6ab0a1e4a8a55e0c54e2151fd0a82a36":[25,40,5],
"group__API__Profiling.html#ga76ad19fc8b99bcd42d505c76aafae6b6":[25,40,18],
"group__API__Profiling.html#ga7c70803a54aa1e5b463ebb19110c4aa2":[25,40,11],
"group__API__Profiling.html#ga858f465a2dcbcadb6169a7926e38a4d1":[25,40,12],
"group__API__Profiling.html#ga87639260ff5c89f466e83fcc093e77fe":[25,40,20],
"group__API__Profiling.html#ga8a423df93ec48a7391b2f439357a5544":[25,40,9],
"group__API__Profiling.html#ga8cbf499dd0d62647b874fcb48c281e6a":[25,40,15],
"group__API__Profiling.html#ga8dc4665fdbbbf8ce8f1b905aa8411642":[25,40,10],
"group__API__Profiling.html#ga8ded3aa2a94ec7a5cd46e2e70a918c65":[25,40,13],
"group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6":[25,40,23],
"group__API__Profiling.html#gabbb944b14c4378e5c855d060c730169b":[25,40,17],
"group__API__Profiling.html#gabd03420d04882a63dea2f39d225ae9d2":[25,40,14],
"group__API__Profiling.html#gabeb22bbe8062a45507cfc6273aae51ae":[25,40,7],
"group__API__Profiling.html#gacf0b5499290848f07c97a32c6c2412db":[25,40,19],
"group__API__Profiling.html#gad04bdc4bfc1e053441ba5c9f3db06a56":[25,40,4],
"group__API__Profiling.html#gad126fc77826a0472b6bd872e7ceb40d4":[25,40,6],
"group__API__Profiling.html#gad38a8e0b33919e560c487c31c404a6ac":[25,40,16],
"group__API__Profiling.html#gaf014e2e050ebd38bc4cffec0081f96bf":[25,40,8],
"group__API__Profiling.html#structstarpu__profiling__bus__info":[25,40,2],
"group__API__Profiling.html#structstarpu__profiling__task__info":[25,40,0],
"group__API__Profiling.html#structstarpu__profiling__worker__info":[25,40,1],
"group__API__Profiling__Tool.html":[25,41],
"group__API__Profiling__Tool.html#ga09fac1d4a77f86153e23aeaf8f066fd2":[25,41,3],
"group__API__Profiling__Tool.html#ga3316011101099a7bc5d68cd260dac1a3":[25,41,5],
"group__API__Profiling__Tool.html#ga459877aae774d6576396522f2f7a935a":[25,41,4],
"group__API__Profiling__Tool.html#ga51982063f84be225d47f8a0635184fe8":[25,41,6],
"group__API__Profiling__Tool.html#ga9b4062bc6c18544ad5a1282672adb644":[25,41,7],
"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info":[25,41,2],
"group__API__Profiling__Tool.html#structstarpu__prof__tool__info":[25,41,0],
"group__API__Profiling__Tool.html#unionstarpu__prof__tool__event__info":[25,41,1],
"group__API__Random__Functions.html":[25,42],
"group__API__Running__Drivers.html":[25,32],
"group__API__Running__Drivers.html#a08415dd427f53b10ce4176ad77fade39":[25,32,0,1],
"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e":[25,32,0,0],
"group__API__Running__Drivers.html#ga119a52234aebe7fef5da42f9d3989402":[25,32,2],
"group__API__Running__Drivers.html#ga497d48a24107dfebf6ef3ad40d4a6df8":[25,32,4],
"group__API__Running__Drivers.html#ga68b320765b17e5e4a256f156c9932e69":[25,32,3],
"group__API__Running__Drivers.html#gab274599ec82fe38cb41267b8a1384995":[25,32,5],
"group__API__Running__Drivers.html#gac8f8848b64980676190d77d265fda841":[25,32,7],
"group__API__Running__Drivers.html#gad6d01b57f2f84df90f554ea205dcf90d":[25,32,6],
"group__API__Running__Drivers.html#structstarpu__driver":[25,32,0],
"group__API__Running__Drivers.html#unionstarpu__driver_8id":[25,32,1],
"group__API__SC__Hypervisor.html":[25,47],
"group__API__SC__Hypervisor.html#a2633e8c38deaef91972fe466983c3869":[25,47,2,8],
"group__API__SC__Hypervisor.html#a29df9c8d9917272bd5fa8f3a08863436":[25,47,2,4],
"group__API__SC__Hypervisor.html#a2e618654e060e8ee020e228085520559":[25,47,2,12],
"group__API__SC__Hypervisor.html#a37e61f63183852ea3f8973f3de5ca23d":[25,47,1,5],
"group__API__SC__Hypervisor.html#a5245eb597997de0cafafe19ece066cdc":[25,47,2,5],
"group__API__SC__Hypervisor.html#a577d9798523bb202f0867ea1a818c88f":[25,47,1,2],
"group__API__SC__Hypervisor.html#a6f4bdf0b6ff0c2ab8d4150e65f2b36e5":[25,47,2,3],
"group__API__SC__Hypervisor.html#a79204440a1911eb6411fa6b8d803e08b":[25,47,1,1],
"group__API__SC__Hypervisor.html#a79c6a87b792c849cc6c388dbf17d2d49":[25,47,1,4],
"group__API__SC__Hypervisor.html#a829c79920efa453ee18491e8a85c1ff6":[25,47,3,3],
"group__API__SC__Hypervisor.html#a838a86b485c9091ab11ea78bfbd12edd":[25,47,2,2],
"group__API__SC__Hypervisor.html#a9a8cebea8354bedd492764a53037f000":[25,47,2,7],
"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d":[25,47,3,1],
"group__API__SC__Hypervisor.html#ab44752ac4a1d34c397d8fe8b10e8611b":[25,47,2,6],
"group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514":[25,47,2,10],
"group__API__SC__Hypervisor.html#ac6da5b817008cd1002fac2412ee1ccde":[25,47,3,2],
"group__API__SC__Hypervisor.html#ac71dc391218a17c435238f6bc42d2250":[25,47,2,0],
"group__API__SC__Hypervisor.html#acc8469538b2b9242e312fea26e13294c":[25,47,3,0],
"group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319":[25,47,2,1],
"group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7":[25,47,1,0],
"group__API__SC__Hypervisor.html#aec206144116e7360d2479a38a1c7f5f4":[25,47,1,3],
"group__API__SC__Hypervisor.html#afbd8b91f7650ffd4c21ecbf17771a3d0":[25,47,2,9],
"group__API__SC__Hypervisor.html#afdc378d28bfed82986912168bab0286b":[25,47,2,11],
"group__API__SC__Hypervisor.html#ga022e4bef8fa4b4e68f071cbaa69c7dd5":[25,47,43],
"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21":[25,47,38],
"group__API__SC__Hypervisor.html#ga04164c5a91df51882e8bdd84fd1b1e3f":[25,47,10],
"group__API__SC__Hypervisor.html#ga0829a2976a7bdba7b3b5ef2124b863b2":[25,47,21],
"group__API__SC__Hypervisor.html#ga08b6cf1458859cdeebc6e53b5dd753cb":[25,47,45],
"group__API__SC__Hypervisor.html#ga0a4b27500994ca2c56047a7da18c6216":[25,47,50],
"group__API__SC__Hypervisor.html#ga3186197ffa198841262a976cb8544ec3":[25,47,28],
"group__API__SC__Hypervisor.html#ga32444b31927fbc49dc721ecbb66eae28":[25,47,47],
"group__API__SC__Hypervisor.html#ga39d8e769961cdc098d0b4cc56653f134":[25,47,31],
"group__API__SC__Hypervisor.html#ga44bf05d5f29cfacfdb178d78f68cab39":[25,47,37],
"group__API__SC__Hypervisor.html#ga44f9db8a2a97ebb45f813006c6fbd88f":[25,47,34],
"group__API__SC__Hypervisor.html#ga4808bbccd3d39478fae09a4feeaf7d65":[25,47,35],
"group__API__SC__Hypervisor.html#ga4a0ceff94ebf33871266bc73b630e9cb":[25,47,20],
"group__API__SC__Hypervisor.html#ga4ab22667e3bd2e963f7451552f716540":[25,47,11],
"group__API__SC__Hypervisor.html#ga562ea43bd369c85d762d49f71eebe928":[25,47,23],
"group__API__SC__Hypervisor.html#ga607deee22e3a1712c11df379be3aa38e":[25,47,53],
"group__API__SC__Hypervisor.html#ga6085b1585a13c94d48f185687c6a117c":[25,47,6],
"group__API__SC__Hypervisor.html#ga6adb0260d4c8a84612c2da05caebe02e":[25,47,16],
"group__API__SC__Hypervisor.html#ga6c0567dc4f96310053c5f953c024e443":[25,47,33],
"group__API__SC__Hypervisor.html#ga70c120158d02e550632de0ec5a207df4":[25,47,4],
"group__API__SC__Hypervisor.html#ga7ba4c0c3deca0dd4148ddd1f0b919792":[25,47,15],
"group__API__SC__Hypervisor.html#ga838703a5d26ea31f7415155ecbf1e490":[25,47,48],
"group__API__SC__Hypervisor.html#ga84e68fc3ee959e12c6b5d49b4db7a441":[25,47,36],
"group__API__SC__Hypervisor.html#ga894cc12da13c7e07534b2f31f8aef02c":[25,47,42],
"group__API__SC__Hypervisor.html#ga94eea335704bbfa52bc025ad4d49eb14":[25,47,9],
"group__API__SC__Hypervisor.html#ga96ec8fb00b7c1a93b7dd9e44deabbe77":[25,47,40],
"group__API__SC__Hypervisor.html#ga9734466cc2ae6b8fcd280a602ac1cf40":[25,47,25],
"group__API__SC__Hypervisor.html#ga9968686b96e842b384e2fd2495c8c7ab":[25,47,27],
"group__API__SC__Hypervisor.html#gaa2299b4916c0e8b3ffe5db762d37d092":[25,47,52],
"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[25,47,51],
"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4":[25,47,7],
"group__API__SC__Hypervisor.html#gab02cf89fff4e322e47bc96fb3b60b1ac":[25,47,44],
"group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad":[25,47,41],
"group__API__SC__Hypervisor.html#gab5a609dbc1fe1703ff8b3d10410f7cc8":[25,47,22],
"group__API__SC__Hypervisor.html#gabcccdef713031ad99b58c302af45fe99":[25,47,32],
"group__API__SC__Hypervisor.html#gabf2475a79863da74418a12b2c5c37871":[25,47,13],
"group__API__SC__Hypervisor.html#gac3b55f616c270eb90c0103d6f062d384":[25,47,14],
"group__API__SC__Hypervisor.html#gac3e457f9b5741f587d241d62cc843f9e":[25,47,12],
"group__API__SC__Hypervisor.html#gad60118273ad73681cd4255cac8a06898":[25,47,18],
"group__API__SC__Hypervisor.html#gad8a9eb41efa7f8a918bc1d7dc8faa400":[25,47,46],
"group__API__SC__Hypervisor.html#gad9267ab01a8e5db5b357d8749f9e8e1a":[25,47,5],
"group__API__SC__Hypervisor.html#gaddb5b0b23b8a3511d85c0340a26da38b":[25,47,30],
"group__API__SC__Hypervisor.html#gae32be23caf7b19b9eab8f334ce8892d1":[25,47,54],
"group__API__SC__Hypervisor.html#gae5459ddc321818abc79d6af96b4af1ab":[25,47,17],
"group__API__SC__Hypervisor.html#gae897baba953584f77fda8c65ae7b25d1":[25,47,29],
"group__API__SC__Hypervisor.html#gaeb8f6b738e6d625ef57a2a687d5bf172":[25,47,26],
"group__API__SC__Hypervisor.html#gaf1f5a13894874d87363c32351f573c86":[25,47,8],
"group__API__SC__Hypervisor.html#gaf3788d6ae764b5864c5d4e74229166c6":[25,47,19],
"group__API__SC__Hypervisor.html#gaf3e884b4995e3dd608120e7fe0e48fae":[25,47,49],
"group__API__SC__Hypervisor.html#gafc5ea604211c8404014f99e4ba161341":[25,47,39],
"group__API__SC__Hypervisor.html#gaffba7dc9450156757654540cc6040bc3":[25,47,24],
"group__API__SC__Hypervisor.html#structsc__hypervisor__policy":[25,47,2],
"group__API__SC__Hypervisor.html#structsc__hypervisor__policy__task__pool":[25,47,1],
"group__API__SC__Hypervisor.html#structsc__hypervisor__resize__ack":[25,47,3],
"group__API__SC__Hypervisor.html#structtypes__of__workers":[25,47,0],
"group__API__SC__Hypervisor__LP.html":[25,48],
"group__API__SC__Hypervisor__LP.html#ga119a16db0b13d9d328b9644fbcfffb33":[25,48,11],
"group__API__SC__Hypervisor__LP.html#ga2cecd17791724a374b6fd2c8e1dff1f6":[25,48,12],
"group__API__SC__Hypervisor__LP.html#ga39b4f48eb3bade0001780c1a1e1c16a8":[25,48,8],
"group__API__SC__Hypervisor__LP.html#ga46fa52870d27246598b657b76d5cbd16":[25,48,9],
"group__API__SC__Hypervisor__LP.html#ga54777bfa24810b101784e5f7e45ff356":[25,48,4],
"group__API__SC__Hypervisor__LP.html#ga563843ede9e369216c3eeb2bd8e5237b":[25,48,6],
"group__API__SC__Hypervisor__LP.html#ga6074d44c0bedd93474d631546b90d602":[25,48,2],
"group__API__SC__Hypervisor__LP.html#ga7ef6d8b50b99d2e88b053791a1d5c588":[25,48,0],
"group__API__SC__Hypervisor__LP.html#ga8e6a76b7b67da9a200bd7755c5af0b0d":[25,48,3],
"group__API__SC__Hypervisor__LP.html#ga9983b17edc20a128abbcdc9d0e6c8a2f":[25,48,10],
"group__API__SC__Hypervisor__LP.html#gacc56bcf1548a4d5a082f9287672fbc13":[25,48,1],
"group__API__SC__Hypervisor__LP.html#gae07ce1123bc39d71ecc437201eac151e":[25,48,5],
"group__API__SC__Hypervisor__LP.html#gafd728af46e35624005c789cdcfdb8a9e":[25,48,7],
"group__API__SC__Hypervisor__usage.html":[25,49],
"group__API__SC__Hypervisor__usage.html#ga00c33eff0501ea8829cf2e7d4954b0fc":[25,49,23],
"group__API__SC__Hypervisor__usage.html#ga07b07d1fe5d41055f451fc92c60361e1":[25,49,1],
"group__API__SC__Hypervisor__usage.html#ga0a20609c85fa479c3fd5892399099416":[25,49,3],
"group__API__SC__Hypervisor__usage.html#ga0f47fee9448054de82ed44f1cb18fdde":[25,49,22],
"group__API__SC__Hypervisor__usage.html#ga1366fc9bb28170e9012dcad441696e52":[25,49,13],
"group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc":[25,49,0],
"group__API__SC__Hypervisor__usage.html#ga37713b9ab6d282f2b705240e630f1a4c":[25,49,10],
"group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[25,49,2],
"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[25,49,18],
"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[25,49,4],
"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[25,49,15]
};
